@@ -9,9 +9,11 @@ compas
 .. toctree::
     :maxdepth: 1
 
+    compas.com
     compas.datastructures
     compas.files
     compas.geometry
+    compas.interop
     compas.numerical
     compas.plotters
     compas.robots
@@ -35,7 +37,7 @@ __copyright__ = 'Copyright 2014-2019 - Block Research Group, ETH Zurich'
 __license__   = 'MIT License'
 __email__     = 'vanmelet@ethz.ch'
 
-__version__ = '0.4.0'
+__version__ = '0.4.2'
 
 
 PY3 = sys.version_info[0] == 3
