@@ -3,14 +3,13 @@ from __future__ import absolute_import
 from __future__ import division
 
 import time
+import compas
 
 try:
     from comtypes.client import CreateObject
     from comtypes.client import GetModule
 except ImportError:
-    import platform
-    if 'windows' in platform.system().lower():
-        raise
+    compas.raise_if_windows()
 
 
 __all__ = ['RhinoClient']
@@ -23,25 +22,24 @@ class RhinoClientError(Exception):
 class RhinoClient(object):
     """Communicate with Rhino through Window's COM interface.
 
-    Parameters
-    ----------
-    delay_start : bool, optional
-        Delay the creation of a COM interface. Default is ``False``.
+    Warning
+    -------
+    This functionality is only available on Windows.
 
     Examples
     --------
-    >>> r = RhinoApp()
-    >>> r.AddPoint(0, 0, 0)
+    >>> rhino = RhinoClient()
+    >>> rhino.start()
+    >>> rhino.show()
+    >>> rhino.top()
+    >>> rhino.AddPoint(0, 0, 0)
     <guid>
 
     """
 
-    def __init__(self, delay_start=False):
+    def __init__(self):
         self.Rhino = None
         self.rs = None
-        if not delay_start:
-            self.start()
-            # self.wait()
 
     def __getattr__(self, name):
         if self.rs:
@@ -76,10 +74,6 @@ class RhinoClient(object):
     def top(self):
         self.Rhino.BringToTop()
 
-    # def wait(self):
-    #     self.rs.GetString('Press enter to exit...', 'exit')
-    #     self.rs.Command('_Exit')
-
 
 # ==============================================================================
 # Main
@@ -89,7 +83,8 @@ if __name__ == "__main__":
 
     Rhino = RhinoClient()
 
+    Rhino.start()
     Rhino.show()
     Rhino.top()
 
-    Rhino.rs.AddPoint([0, 0, 0])
+    Rhino.AddPoint([0, 0, 0])
